==> knative-model-4.7.2-sources.jar: io/fabric8/knative/serving/v1alpha1/RevisionTemplateSpecFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RevisionTemplateSpecFluent<A extends io.fabric8.knative.serving.v1alpha1.RevisionTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public RevisionTemplateSpecFluent.MetadataNested<A> editMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.serving.v1alpha1.RevisionSpec getSpec();
    public io.fabric8.knative.serving.v1alpha1.RevisionSpec buildSpec();
    public A withSpec(io.fabric8.knative.serving.v1alpha1.RevisionSpec spec);
    public Boolean hasSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.RevisionSpec item);
    public RevisionTemplateSpecFluent.SpecNested<A> editSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.RevisionSpec item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<RevisionTemplateSpecFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.RevisionSpecFluent<RevisionTemplateSpecFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> knative-model-4.10.0-sources.jar: io/fabric8/knative/serving/v1alpha1/RevisionTemplateSpecFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RevisionTemplateSpecFluent<A extends io.fabric8.knative.serving.v1alpha1.RevisionTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public RevisionTemplateSpecFluent.MetadataNested<A> editMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public io.fabric8.knative.serving.v1alpha1.RevisionSpec getSpec();
    public io.fabric8.knative.serving.v1alpha1.RevisionSpec buildSpec();
    public A withSpec(io.fabric8.knative.serving.v1alpha1.RevisionSpec spec);
    public Boolean hasSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpecLike(io.fabric8.knative.serving.v1alpha1.RevisionSpec item);
    public RevisionTemplateSpecFluent.SpecNested<A> editSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.knative.serving.v1alpha1.RevisionSpec item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<RevisionTemplateSpecFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.RevisionSpecFluent<RevisionTemplateSpecFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
